pub struct ObserverWithCondition<E, B, M, S>{ /* private fields */ }Expand description
An observer system with run conditions that preserves event type information.
This type is returned by ObserverSystemExt::run_if
and allows entity.observe(system.run_if(cond)) to work with compile-time
verification that the event implements EntityEvent.
Implementations
Sourceimpl<E, B, M, S> ObserverWithCondition<E, B, M, S>
impl<E, B, M, S> ObserverWithCondition<E, B, M, S>
Sourcepub fn run_if<C, CM>(self, condition: C) -> ObserverWithCondition<E, B, M, S>where
C: SystemCondition<CM>,
pub fn run_if<C, CM>(self, condition: C) -> ObserverWithCondition<E, B, M, S>where
C: SystemCondition<CM>,
Adds another run condition to this observer.
All conditions must return true for the observer to run (AND semantics).
Note: Chained .run_if() calls do not short-circuit — all conditions
run every time to maintain correct change detection ticks. If you need
short-circuit behavior, use .run_if(a.and(b)), but be aware this may cause
stale Changed<T> detection if the second condition is frequently skipped.
Example
world.add_observer(
on_event
.run_if(|a: Res<CondA>| a.0)
.run_if(|b: Res<CondB>| b.0)
);Auto Trait Implementations
impl<E, B, M, S> Freeze for ObserverWithCondition<E, B, M, S>where
S: Freeze,
impl<E, B, M, S> !RefUnwindSafe for ObserverWithCondition<E, B, M, S>
impl<E, B, M, S> Send for ObserverWithCondition<E, B, M, S>
impl<E, B, M, S> Sync for ObserverWithCondition<E, B, M, S>where
S: Sync,
impl<E, B, M, S> Unpin for ObserverWithCondition<E, B, M, S>where
S: Unpin,
impl<E, B, M, S> UnsafeUnpin for ObserverWithCondition<E, B, M, S>where
S: UnsafeUnpin,
impl<E, B, M, S> !UnwindSafe for ObserverWithCondition<E, B, M, S>