pub trait IntoEntityObserver<Marker>: Send + 'static {
// Required method
fn into_observer_for_entity(self, entity: Entity) -> Observer;
}Expand description
Trait for types that can be converted into an entity-targeting Observer.
This trait enforces that the event type implements EntityEvent.
Required Methods
Sourcefn into_observer_for_entity(self, entity: Entity) -> Observer
fn into_observer_for_entity(self, entity: Entity) -> Observer
Converts this type into an Observer that watches the given entity.